@@ -9,17 +9,17 @@
 #ifndef KWINCONFIG_H
 #define KWINCONFIG_H
 
+#define KWIN_PLUGIN_VERSION_STRING "5.23.2"
+
 /*
- 
+
  These should be primarily used to detect what kind of compositing
  support is available.
 
 */
 
-/* KWIN_HAVE_XRENDER_COMPOSITING - whether XRender-based compositing support is available */
-#define KWIN_HAVE_XRENDER_COMPOSITING
-
 #define HAVE_EPOXY_GLX 1
 
+#define HAVE_DL_LIBRARY 1
 
 #endif
